paradag
=======

.. image:: https://img.shields.io/pypi/v/paradag.svg
   :target: https://pypi.python.org/pypi/paradag
   :alt: PyPI

.. image:: https://travis-ci.org/xianghuzhao/paradag.svg?branch=master
   :target: https://travis-ci.org/xianghuzhao/paradag
   :alt: Travis CI Status

.. image:: https://codeclimate.com/github/xianghuzhao/paradag/badges/gpa.svg
   :target: https://codeclimate.com/github/xianghuzhao/paradag
   :alt: Code Climate

A robust DAG package for easy parallel execution.

paradag is implemented in pure python and totally independent of any
other packages.
